@@ -4,19 +4,12 @@
 # conda is distributed under the terms of the BSD 3-clause license.
 # Consult LICENSE.txt or http://opensource.org/licenses/BSD-3-Clause.
 
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-import logging
-import re
 from argparse import RawDescriptionHelpFormatter
+import logging
 from os.path import isdir, isfile
-
-from .common import (add_parser_help, add_parser_json, add_parser_prefix,
-                     add_parser_show_channel_urls, disp_features, stdout_json)
-from ..base.context import context
-from ..egg_info import get_egg_info
-from ..exceptions import CondaEnvironmentNotFoundError, CondaFileNotFoundError
-from ..install import dist2quad, is_linked, linked, linked_data, name_dist
+import re
 
 descr = "List linked packages in a conda environment."
 
@@ -44,6 +37,9 @@ Reinstall packages from an export file:
 log = logging.getLogger(__name__)
 
 def configure_parser(sub_parsers):
+    from .common import (add_parser_help, add_parser_json, add_parser_prefix,
+                         add_parser_show_channel_urls)
+
     p = sub_parsers.add_parser(
         'list',
         description=descr,
@@ -103,16 +99,16 @@ def configure_parser(sub_parsers):
     p.set_defaults(func=execute)
 
 
-def print_export_header():
+def print_export_header(subdir):
     print('# This file may be used to create an environment using:')
     print('# $ conda create --name <env> --file <this file>')
-    print('# platform: %s' % context.subdir)
+    print('# platform: %s' % subdir)
 
 
 def get_packages(installed, regex):
     pat = re.compile(regex, re.I) if regex else None
-    for dist in sorted(installed, key=lambda x: name_dist(x).lower()):
-        name = name_dist(dist)
+    for dist in sorted(installed, key=lambda x: x.quad[0].lower()):
+        name = dist.quad[0]
         if pat and pat.search(name) is None:
             continue
 
@@ -120,7 +116,11 @@ def get_packages(installed, regex):
 
 
 def list_packages(prefix, installed, regex=None, format='human',
-                  show_channel_urls=context.show_channel_urls):
+                  show_channel_urls=None):
+    from .common import disp_features
+    from ..base.constants import DEFAULTS_CHANNEL_NAME
+    from ..base.context import context
+    from ..core.linked_data import is_linked
     res = 0
     result = []
     for dist in get_packages(installed, regex):
@@ -128,7 +128,7 @@ def list_packages(prefix, installed, regex=None, format='human',
             result.append(dist)
             continue
         if format == 'export':
-            result.append('='.join(dist2quad(dist)[:3]))
+            result.append('='.join(dist.quad[:3]))
             continue
 
         try:
@@ -138,19 +138,28 @@ def list_packages(prefix, installed, regex=None, format='human',
             disp = '%(name)-25s %(version)-15s %(build)15s' % info
             disp += '  %s' % disp_features(features)
             schannel = info.get('schannel')
-            if show_channel_urls or show_channel_urls is None and schannel != 'defaults':
+            show_channel_urls = show_channel_urls or context.show_channel_urls
+            if (show_channel_urls or show_channel_urls is None
+                    and schannel != DEFAULTS_CHANNEL_NAME):
                 disp += '  %s' % schannel
             result.append(disp)
         except (AttributeError, IOError, KeyError, ValueError) as e:
             log.debug("exception for dist %s:\n%r", dist, e)
-            result.append('%-25s %-15s %15s' % dist2quad(dist)[:3])
+            result.append('%-25s %-15s %15s' % tuple(dist.quad[:3]))
 
     return res, result
 
 
 def print_packages(prefix, regex=None, format='human', piplist=False,
-                   json=False, show_channel_urls=context.show_channel_urls):
+                   json=False, show_channel_urls=None):
+    from .common import stdout_json
+    from ..base.context import context
+    from ..common.compat import text_type
+    from ..core.linked_data import linked
+    from ..egg_info import get_egg_info
+
     if not isdir(prefix):
+        from ..exceptions import CondaEnvironmentNotFoundError
         raise CondaEnvironmentNotFoundError(prefix)
 
     if not json:
@@ -158,7 +167,7 @@ def print_packages(prefix, regex=None, format='human', piplist=False,
             print('# packages in environment at %s:' % prefix)
             print('#')
         if format == 'export':
-            print_export_header()
+            print_export_header(context.subdir)
 
     installed = linked(prefix)
     log.debug("installed conda packages:\n%s", installed)
@@ -170,20 +179,24 @@ def print_packages(prefix, regex=None, format='human', piplist=False,
     exitcode, output = list_packages(prefix, installed, regex, format=format,
                                      show_channel_urls=show_channel_urls)
     if not json:
-        print('\n'.join(output))
+        print('\n'.join(map(text_type, output)))
     else:
         stdout_json(output)
     return exitcode
 
 
 def print_explicit(prefix, add_md5=False):
+    from ..base.constants import UNKNOWN_CHANNEL
+    from ..base.context import context
+    from ..core.linked_data import linked_data
     if not isdir(prefix):
+        from ..exceptions import CondaEnvironmentNotFoundError
         raise CondaEnvironmentNotFoundError(prefix)
-    print_export_header()
+    print_export_header(context.subdir)
     print("@EXPLICIT")
     for meta in sorted(linked_data(prefix).values(), key=lambda x: x['name']):
         url = meta.get('url')
-        if not url or url.startswith('<unknown>'):
+        if not url or url.startswith(UNKNOWN_CHANNEL):
             print('# no URL for: %s' % meta['fn'])
             continue
         md5 = meta.get('md5')
@@ -191,14 +204,15 @@ def print_explicit(prefix, add_md5=False):
 
 
 def execute(args, parser):
+    from ..base.context import context
+    from .common import stdout_json
     prefix = context.prefix_w_legacy_search
     regex = args.regex
     if args.full_name:
         regex = r'^%s$' % regex
 
     if args.revisions:
-        from conda.history import History
-
+        from ..history import History
         h = History(prefix)
         if isfile(h.path):
             if not context.json:
@@ -206,7 +220,8 @@ def execute(args, parser):
             else:
                 stdout_json(h.object_log())
         else:
-            raise CondaFileNotFoundError(h.path, "No revision log found: %s\n" % h.path)
+            from ..exceptions import CondaFileNotFoundError
+            raise CondaFileNotFoundError(h.path)
         return
 
     if args.explicit:
