@@ -637,6 +637,7 @@ class Resolve(object):
         return {self.push_MatchSpec(C, nm): 1 for nm in missing}
 
     def generate_version_metrics(self, C, specs, include0=False):
+        eqc = {}  # a C.minimize() objective: Dict[varname, coeff]
         eqv = {}  # a C.minimize() objective: Dict[varname, coeff]
         eqb = {}  # a C.minimize() objective: Dict[varname, coeff]
         sdict = {}  # Dict[package_name, Dist]
@@ -660,25 +661,28 @@ class Resolve(object):
                 if targets and any(dist == t for t in targets):
                     continue
                 if pkey is None:
+                    ic = iv = ib = 0
+                # valid package, channel priority
+                elif pkey[0] != version_key[0] or pkey[1] != version_key[1]:
+                    ic += 1
                     iv = ib = 0
-                # any version number mismatch (each character compared one by one)
-                elif any(pk != vk for pk, vk in zip(pkey[:3], version_key[:3])):
+                # version
+                elif pkey[2] != version_key[2]:
                     iv += 1
                     ib = 0
-                # build number
-                elif pkey[3] != version_key[3]:
-                    ib += 1
-                # last field is timestamp. Use it as differentiator when build numbers are similar
-                elif pkey[4] != version_key[4]:
+                # build number, timestamp
+                elif pkey[3] != version_key[3] or pkey[4] != version_key[4]:
                     ib += 1
 
+                if ic or include0:
+                    eqc[dist.full_name] = ic
                 if iv or include0:
                     eqv[dist.full_name] = iv
                 if ib or include0:
                     eqb[dist.full_name] = ib
                 pkey = version_key
 
-        return eqv, eqb
+        return eqc, eqv, eqb
 
     def dependency_sort(self, must_have):
         # type: (Dict[package_name, Dist]) -> List[Dist]
@@ -884,9 +888,10 @@ class Resolve(object):
             log.debug('Package removal metric: %d', obj7)
 
             # Requested packages: maximize versions
-            eq_req_v, eq_req_b = r2.generate_version_metrics(C, specr)
+            eq_req_c, eq_req_v, eq_req_b = r2.generate_version_metrics(C, specr)
+            solution, obj3a = C.minimize(eq_req_c, solution)
             solution, obj3 = C.minimize(eq_req_v, solution)
-            log.debug('Initial package version metric: %d', obj3)
+            log.debug('Initial package version metric: %d/%d', obj3a, obj3)
 
             # Track features: minimize feature count
             eq_feature_count = r2.generate_feature_count(C)
@@ -909,10 +914,11 @@ class Resolve(object):
             log.debug('Dependency update count: %d', obj50)
 
             # Remaining packages: maximize versions, then builds
-            eq_v, eq_b = r2.generate_version_metrics(C, speca)
+            eq_c, eq_v, eq_b = r2.generate_version_metrics(C, speca)
+            solution, obj5a = C.minimize(eq_c, solution)
             solution, obj5 = C.minimize(eq_v, solution)
             solution, obj6 = C.minimize(eq_b, solution)
-            log.debug('Additional package version/build metrics: %d/%d', obj5, obj6)
+            log.debug('Additional package version/build metrics: %d/%d/%d', obj5a, obj5, obj6)
 
             # Prune unnecessary packages
             eq_c = r2.generate_package_count(C, specm)
