@@ -1,10 +1,10 @@
-from __future__ import print_function, division, absolute_import
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import operator as op
 import re
 
-from .compat import zip_longest, string_types, zip
-from .exceptions import CondaRuntimeError, CondaValueError
+from .common.compat import string_types, zip, zip_longest
+from .exceptions import CondaValueError, InvalidSpecError
 
 
 # normalized_version() is needed by conda-env
@@ -20,8 +20,11 @@ def ver_eval(vtest, spec):
 
 version_check_re = re.compile(r'^[\*\.\+!_0-9a-z]+$')
 version_split_re = re.compile('([0-9]+|[*]+|[^0-9*]+)')
+version_cache = {}
+
+
 class VersionOrder(object):
-    '''
+    """
     This class implements an order relation between version strings.
     Version strings can contain the usual alphanumeric characters
     (A-Za-z0-9), separated into components by dots and underscores. Empty
@@ -128,8 +131,16 @@ class VersionOrder(object):
     this problem by appending a dash to plain version numbers:
 
       1.0.1a  =>  1.0.1post.a      # ensure correct ordering for openssl
-    '''
-    def __init__(self, version):
+    """
+
+    def __new__(cls, version):
+        if isinstance(version, cls):
+            return version
+        self = version_cache.get(version)
+        if self is not None:
+            return self
+        self = version_cache[version] = object.__new__(cls)
+
         # when fillvalue ==  0  =>  1.1 == 1.1.0
         # when fillvalue == -1  =>  1.1  < 1.1.0
         self.fillvalue = 0
@@ -200,6 +211,7 @@ class VersionOrder(object):
                     # components shall start with a number to keep numbers and
                     # strings in phase => prepend fillvalue
                     v[k] = [self.fillvalue] + c
+        return self
 
     def __str__(self):
         return self.norm_version
@@ -330,7 +342,7 @@ class VersionSpec(object):
         elif spec.startswith(('=', '<', '>', '!')):
             m = version_relation_re.match(spec)
             if m is None:
-                raise CondaRuntimeError('Invalid version spec: %s' % spec)
+                raise InvalidSpecError(spec)
             op, b = m.groups()
             self.op = opdict[op]
             self.cmp = VersionOrder(b)
