@@ -4,6 +4,8 @@ Functions related to core conda functionality that relates to pip
 NOTE: This modules used to in conda, as conda/pip.py
 """
 from __future__ import absolute_import, print_function
+
+import os
 from os.path import isfile, join
 import re
 import subprocess
@@ -52,9 +54,11 @@ def installed(prefix, output=True):
     if args is None:
         return
     args.append('list')
+    env = os.environ.copy()
+    env[str('PIP_FORMAT')] = str('legacy')
     try:
         pipinst = subprocess.check_output(
-            args, universal_newlines=True
+            args, universal_newlines=True, env=env,
         ).splitlines()
     except Exception:
         # Any error should just be ignored
@@ -100,14 +104,14 @@ def installed(prefix, output=True):
 
 def add_pip_installed(prefix, installed_pkgs, json=None, output=True):
     # Defer to json for backwards compatibility
-    if type(json) is bool:
+    if isinstance(json, bool):
         output = not json
 
     # TODO Refactor so installed is a real list of objects/dicts
     #      instead of strings allowing for direct comparison
     # split :: to get rid of channel info
-    conda_names = {d.rsplit('-', 2)[0].split("::")[-1] for d in installed_pkgs}
+    conda_names = {d.quad[0] for d in installed_pkgs}
     for pip_pkg in installed(prefix, output=output):
-        if pip_pkg['name'] in conda_names and not 'path' in pip_pkg:
+        if pip_pkg['name'] in conda_names and 'path' not in pip_pkg:
             continue
         installed_pkgs.add(str(pip_pkg))
